@@ -9,6 +9,7 @@ from sqlglot.dialects.dialect import (
     no_ilike_sql,
 )
 from sqlglot.generator import Generator
+from sqlglot.parser import Parser
 from sqlglot.tokens import Tokenizer, TokenType
 
 
@@ -22,6 +23,12 @@ class SQLite(Dialect):
             "NVARCHAR": TokenType.VARCHAR,
         }
 
+    class Parser(Parser):
+        FUNCTIONS = {
+            **Parser.FUNCTIONS,
+            "EDITDIST3": exp.Levenshtein.from_arg_list,
+        }
+
     class Generator(Generator):
         TYPE_MAPPING = {
             exp.DataType.Type.BOOLEAN: "INTEGER",
