@@ -1750,22 +1750,10 @@ class Bracket(Condition):
     arg_types = {"this": True, "expressions": True}
 
 
-class Case(Condition):
-    arg_types = {"this": False, "ifs": True, "default": False}
-
-
-class Cast(Expression):
-    arg_types = {"this": True, "to": True}
-
-
 class Distinct(Expression):
     arg_types = {"this": False, "on": False}
 
 
-class Extract(Expression):
-    arg_types = {"this": True, "expression": True}
-
-
 class In(Predicate):
     arg_types = {"this": True, "expressions": False, "query": False, "unnest": False}
 
@@ -1792,10 +1780,6 @@ class IgnoreNulls(Expression):
     pass
 
 
-class TryCast(Cast):
-    pass
-
-
 # Functions
 class Func(Condition):
     """
@@ -1916,6 +1900,18 @@ class Avg(AggFunc):
     pass
 
 
+class Case(Func):
+    arg_types = {"this": False, "ifs": True, "default": False}
+
+
+class Cast(Func):
+    arg_types = {"this": True, "to": True}
+
+
+class TryCast(Cast):
+    pass
+
+
 class Ceil(Func):
     _sql_names = ["CEIL", "CEILING"]
 
@@ -1982,6 +1978,10 @@ class DatetimeTrunc(Func, TimeUnit):
     arg_types = {"this": True, "unit": True, "zone": False}
 
 
+class Extract(Func):
+    arg_types = {"this": True, "expression": True}
+
+
 class TimestampAdd(Func, TimeUnit):
     arg_types = {"this": True, "expression": True, "unit": False}
 
